agentle.mcp.sampling
====================

.. automodule:: agentle.mcp.sampling

   
   .. rubric:: Classes

   .. autosummary::
   
      CompletionResult
      Hint
      ModelPreference
      SamplingRequest
   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   completion_result
   hint
   messages
   model_preferences
   request
